API
===

There are 2 interfaces:
 - pysimavr.swig.*: low level, generated by swig
 - pysimavr.*: high level classes, they can redirect function calls 
   to low level interface. Example: Avr class (high level) 
   has all properties and methods of avr_t class (low level) automatically.
 
low level interface
-----------------------

.. automodule:: pysimavr.swig.ac_input
    :members:
    :undoc-members:

.. automodule:: pysimavr.swig.hd44780
    :members:
    :undoc-members:

.. automodule:: pysimavr.swig.inverter
    :members:
    :undoc-members:


.. automodule:: pysimavr.swig.ledrow
    :members:
    :undoc-members:


.. automodule:: pysimavr.swig.sgm7
    :members:
    :undoc-members:


.. automodule:: pysimavr.swig.simavr
    :members:
    :undoc-members:

high level interface
-----------------------

.. automodule:: pysimavr.ac
    :members:
    :undoc-members:

.. automodule:: pysimavr.avr
    :members:
    :undoc-members:

.. automodule:: pysimavr.connect
    :members:
    :undoc-members:

.. automodule:: pysimavr.firmware
    :members:
    :undoc-members:

.. automodule:: pysimavr.inverter
    :members:
    :undoc-members:

.. automodule:: pysimavr.lcd
    :members:
    :undoc-members:

.. automodule:: pysimavr.ledrow
    :members:
    :undoc-members:

.. automodule:: pysimavr.sgm7
    :members:
    :undoc-members:

.. automodule:: pysimavr.vcdfile
    :members:
    :undoc-members:








    